#!/bin/bash

set -e

base_img=$1
dir=NxGBSMedia
project=vg_gbs_media
version=$(cat ${dir}/VERSION)
target_img=${project}:${version}

if [ -z ${base_img} ]
then
    echo "参数错误!"
    echo "  $0 <基础镜像名>"
    exit 1
fi

if ! docker inspect ${base_img} >/dev/null 2>&1
then
    echo "${base_img} 基础镜像不存在!"
    exit 1
fi

if [ ! -d ${dir} ]
then
    echo "程序目录不存在!"
    exit 1
fi

files=$(find ${dir} -type f)
if [ -z "${files}" ]
then
    echo "程序目录为空或不存在任何文件!"
    exit 1
fi

if docker inspect ${target_img} >/dev/null 2>&1
then
    echo "${target_img} 目标镜像存在，备份镜像：${target_img}.$(date +%Y%m%d%H%M%S)"
    docker tag ${target_img} ${target_img}.$(date +%Y%m%d%H%M%S)
fi

cat >> Dockerfile <<EOF
FROM ${base_img}
COPY ./${dir} /${dir}
ENV LD_LIBRARY_PATH \${LD_LIBRARY_PATH:+\$LD_LIBRARY_PATH:}/${dir}/lib
ENV LC_ALL C.UTF-8
EXPOSE 8814
WORKDIR /${dir}
VOLUME ["/log"]
ENTRYPOINT ["bin/NxGBSMedia", "-log_dir=/log", "-max_log_size=10"]
EOF

docker build --no-cache -t ${target_img} .